@@ -85,15 +85,14 @@ impl Hasher for SoftwareVault {
 #[cfg(test)]
 mod tests {
     use crate::SoftwareVault;
-    use ockam_vault_test_attribute::*;
 
     fn new_vault() -> SoftwareVault {
         SoftwareVault::default()
     }
 
-    #[vault_test]
+    #[ockam_macros::vault_test]
     fn sha256() {}
 
-    #[vault_test]
+    #[ockam_macros::vault_test]
     fn hkdf() {}
 }
